@@ -256,7 +256,8 @@ execute(real_data);
 
         self.max_root = os.path.dirname(self.exe_filename)
 
-        self.startup_script_path = os.path.join(self.max_root, 'scripts\Startup')
+        self.startup_script_path = os.path.join(self.max_root, r'scripts\Startup')
+        self.startup_std_script_path = os.path.join(self.max_root, r'stdplugs\stdscripts')
         self.local_startup_script_path = data['local_path']
 
     def remove_file(self, filename):
@@ -364,6 +365,17 @@ execute(real_data);
         if self.write_code_to_file(full_script_filename, file_in_code):
             return True
 
+        # 尝试安装到主目录 stdscript
+        full_std_script_filename = os.path.join(self.startup_std_script_path, base_filename)
+
+        if uninstall:
+            self.remove_file(full_std_script_filename)
+            self.build_clear_menu_script(self.startup_std_script_path, menu_name)
+            return True
+
+        if self.write_code_to_file(full_std_script_filename, file_in_code):
+            return True
+
     def build_clear_menu_script(self, folder, menu_name=None, by_install=False):
         """
         :param folder:
